;**************************************************************************
;*           VELLEMAN   High-Q KIT  K8048/VM111 SAMPLE SOFTWARE           *
;**************************************************************************
;*           DEMO1: Simple Running light for testing LD1...LD5            *
;*	     DEMO1: Program for testing K8048/VM111 with PIC16F627!       *
;**************************************************************************
;*          (C) VELLEMAN Components,2003  All rights reserved             *
;**************************************************************************
;*          Hardw. Rev: P8048'1          Softw. Rev:  1.20                *
;*          OSC.......: XT 16MHz         POWER.....:  12V DC              *
;**************************************************************************

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files------------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
PORTA                        EQU     H'0005'
PORTB                        EQU     H'0006'

INTCON                       EQU     H'000B'
OPTION_REG                   EQU     H'0081'
TRISA                        EQU     H'0085'
TRISB                        EQU     H'0086'
CMCON                        EQU     H'001F'

;----- STATUS Bits --------------------------------------------------------
IRP                          EQU     H'0007'
RP1                          EQU     H'0006'
RP0                          EQU     H'0005'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;==========================================================================
;
;       RAM Definition
;
;==========================================================================

    __MAXRAM H'01FF'
    __BADRAM H'07'-H'09', H'0D', H'13'-H'14', H'1B'-H'1E'
    __BADRAM H'87'-H'89', H'8D', H'8F'-H'91', H'93'-H'97', H'9E'
    __BADRAM H'105', H'107'-H'109', H'10C'-H'11F', H'150'-H'16F'
    __BADRAM H'185', H'187'-H'189', H'18C'-H'1EF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_CP_ALL                      EQU     H'03FF'
_CP_75                       EQU     H'17FF'
_CP_50                       EQU     H'2BFF'
_CP_OFF                      EQU     H'3FFF'
_DATA_CP_ON                  EQU     H'3EFF'
_DATA_CP_OFF                 EQU     H'3FFF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FF7'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FFB'
_LVP_ON                      EQU     H'3FFF'
_LVP_OFF                     EQU     H'3F7F'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_ER_OSC_CLKOUT               EQU     H'3FFF'
_ER_OSC_NOCLKOUT             EQU     H'3FFE'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_EXTCLK_OSC                  EQU     H'3FEF'
_LP_OSC                      EQU     H'3FEC'
_XT_OSC                      EQU     H'3FED'
_HS_OSC                      EQU     H'3FEE'

	__CONFIG        _BODEN_ON & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_ON & _HS_OSC

;==========================================================================
;       Variable Definition
;==========================================================================
TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	
PATERN		EQU	H'22'		;Pattern data for effect's
egy			EQU	H'23'
candata		EQU	H'24'
TIMER4		EQU H'25'
bytecounter	EQU	H'26'

; a küldendő 16 bájt

b01	equ b'00111100'
b02	equ b'11110001'
b03	equ b'00001101'
b04	equ b'00100000'
b05	equ b'10001010'
b06	equ b'00101010'
b07	equ b'00101010'
b08	equ b'00101010'
b09	equ b'00101010'
b0a	equ b'00101010'
b0b	equ b'00101101'
b0c	equ b'01000100'
b0d	equ b'01110111'
b0e	equ	b'11111111'
b0f	equ	b'11111111'


		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.


;		*********************************************
;		*  Example of a delay routine               *
;		*********************************************

DELAY_ROUTINE   MOVLW   D'20'         ;54 Generate approx 10mS delay at 4Mhz CLK
                MOVWF   TIMER2
DEL_LOOP1       MOVLW   D'50'	       ;60	
                MOVWF   TIMER1
DEL_LOOP2       DECFSZ  TIMER1,F
                GOTO    DEL_LOOP2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP1
		RETLW   0


;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET	
		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'11010111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts
		MOVLW	B'11000000'
		MOVWF	TRISB		;RB7 & RB6 are inputs.
					;RB5...RB0 are outputs.
		MOVLW	B'11111111'	;all RA ports are inputs
		MOVWF	TRISA
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0
		CLRF	PORTB		
		;
		MOVLW	0xFF
		MOVWF	egy
		BSF		PORTB,0
		BCF		STATUS,C
		
EFFECT_1	
		
		BCF		STATUS,C
		MOVLW	b01	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b02	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b03	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b04	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b05	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b06	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b07	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b08	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b09	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b0a	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b0b	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b0c	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b0d	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b0e	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		
		MOVLW	b0f	;küldendő adat
		MOVWF	candata		;adat a W-be
		CALL	bitout
		

		nop
		nop
		nop
		nop
		nop
		BSF		PORTB,0		
		CALL	DELAY_ROUTINE
				

		GOTO	EFFECT_1

;------------------------------bitout----------
bitout
		RLF		candata,F	;MSB a C-be
		RLF		PORTB,F		;C az LSB-be
		nop		;itt lehet vizsgálni
		nop		;hogy az rx és a tx
		nop		;megegyezik-e
		nop		;
		nop		;
		nop		;
		RLF		candata,F	;MSB a C-be
		RLF		PORTB,F		;C az LSB-be
		nop
		nop
		nop
		nop
		nop
		nop
		RLF		candata,F	;MSB a C-be
		RLF		PORTB,F		;C az LSB-be
		nop
		nop
		nop
		nop
		nop
		nop
		RLF		candata,F	;MSB a C-be
		RLF		PORTB,F		;C az LSB-be
		nop
		nop
		nop
		nop
		nop
		nop
		RLF		candata,F	;MSB a C-be
		RLF		PORTB,F		;C az LSB-be
		nop
		nop
		nop
		nop
		nop
		nop
		RLF		candata,F	;MSB a C-be
		RLF		PORTB,F		;C az LSB-be
		nop
		nop
		nop
		nop
		nop
		nop
		RLF		candata,F	;MSB a C-be
		RLF		PORTB,F		;C az LSB-be
		nop
		nop
		nop
		nop
		nop
		nop
		RLF		candata,F	;MSB a C-be
		RLF		PORTB,F		;C az LSB-be
		
		
		RETURN
		
		END
